==> percona-xtrabackup_8.0.35-30.orig.tar.gz: percona-xtrabackup-8.0.35-30/storage/ndb/clusterj/clusterj-core/src/main/java/com/mysql/clusterj/core/store/ClusterTransaction.java <==
/*
   Copyright (c) 2009, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

package com.mysql.clusterj.core.store;

import com.mysql.clusterj.LockMode;

/**
 *
 */
public interface ClusterTransaction {

    public void close();

    public void executeCommit();

    public void executeCommit(boolean abort, boolean force);

    public void executeNoCommit(boolean abort, boolean force);

    public void executeNoCommit();

    public void executeRollback();

    public Operation getSelectOperation(Table storeTable);

    public Operation getInsertOperation(Table storeTable);

    public Operation getUpdateOperation(Table storeTable);

    public Operation getWriteOperation(Table storeTable);

    public Operation getDeleteOperation(Table storeTable);

    public IndexOperation getUniqueIndexOperation(Index storeIndex, Table storeTable);

    public IndexOperation getUniqueIndexDeleteOperation(Index storeIndex, Table storeTable);

    public IndexOperation getUniqueIndexUpdateOperation(Index storeIndex, Table storeTable);

    public IndexScanOperation getIndexScanOperation(Index storeIndex, Table storeTable);

    public IndexScanOperation getIndexScanOperationLockModeExclusiveScanFlagKeyInfo(Index storeIndex, Table storeTable);

    public IndexScanOperation getIndexScanOperationMultiRange(Index storeIndex, Table storeTable);

    public ScanOperation getTableScanOperation(Table storeTable);

    public ScanOperation getTableScanOperationLockModeExclusiveScanFlagKeyInfo(Table storeTable);

    public boolean isEnlisted();

    public void setPartitionKey(PartitionKey partitionKey);

    public String getCoordinatedTransactionId();

    public void setCoordinatedTransactionId(String coordinatedTransactionId);

    public void setLockMode(LockMode lockmode);

    public void setAutocommit(boolean autocommit);

    public void postExecuteCallback(Runnable postExecuteCallbackHandler);

}

==> percona-xtrabackup_8.4.0-1.orig.tar.gz: percona-xtrabackup-8.4.0-1/storage/ndb/clusterj/clusterj-core/src/main/java/com/mysql/clusterj/core/store/ClusterTransaction.java <==
/*
   Copyright (c) 2009, 2024, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

package com.mysql.clusterj.core.store;

import com.mysql.clusterj.LockMode;

/**
 *
 */
public interface ClusterTransaction {

    public void close();

    public void executeCommit();

    public void executeCommit(boolean abort, boolean force);

    public void executeNoCommit(boolean abort, boolean force);

    public void executeNoCommit();

    public void executeRollback();

    public Operation getSelectOperation(Table storeTable);

    public Operation getInsertOperation(Table storeTable);

    public Operation getUpdateOperation(Table storeTable);

    public Operation getWriteOperation(Table storeTable);

    public Operation getDeleteOperation(Table storeTable);

    public IndexOperation getUniqueIndexOperation(Index storeIndex, Table storeTable);

    public IndexOperation getUniqueIndexDeleteOperation(Index storeIndex, Table storeTable);

    public IndexOperation getUniqueIndexUpdateOperation(Index storeIndex, Table storeTable);

    public IndexScanOperation getIndexScanOperation(Index storeIndex, Table storeTable);

    public IndexScanOperation getIndexScanOperationLockModeExclusiveScanFlagKeyInfo(Index storeIndex, Table storeTable);

    public IndexScanOperation getIndexScanOperationMultiRange(Index storeIndex, Table storeTable);

    public ScanOperation getTableScanOperation(Table storeTable);

    public ScanOperation getTableScanOperationLockModeExclusiveScanFlagKeyInfo(Table storeTable);

    public boolean isEnlisted();

    public void setPartitionKey(PartitionKey partitionKey);

    public String getCoordinatedTransactionId();

    public void setCoordinatedTransactionId(String coordinatedTransactionId);

    public void setLockMode(LockMode lockmode);

    public void setAutocommit(boolean autocommit);

    public void postExecuteCallback(Runnable postExecuteCallbackHandler);

}
